aboutsummaryrefslogtreecommitdiffstats
path: root/packet-ieee80211.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2003-12-20 03:21:20 +0000
committerGuy Harris <guy@alum.mit.edu>2003-12-20 03:21:20 +0000
commit1a347fc00ff16ac41b2e4f785d18eaa5615d49bd (patch)
treed8ee5c52fb5fb145496d41317309df525d40cb8d /packet-ieee80211.c
parent39f5418dc0d40df41f329c4b9eeb59fd5a530e9a (diff)
Do the special "if the first fragment we see is also the final fragment,
treat it as a reassembled frame" hack *only* for 802.11, as that's the only protocol we know of that requires it. svn path=/trunk/; revision=9367
Diffstat (limited to 'packet-ieee80211.c')
-rw-r--r--packet-ieee80211.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/packet-ieee80211.c b/packet-ieee80211.c
index ab3f843332..03f284249f 100644
--- a/packet-ieee80211.c
+++ b/packet-ieee80211.c
@@ -3,7 +3,7 @@
* Copyright 2000, Axis Communications AB
* Inquiries/bugreports should be sent to Johan.Jorgensen@axis.com
*
- * $Id: packet-ieee80211.c,v 1.101 2003/09/24 23:35:39 guy Exp $
+ * $Id: packet-ieee80211.c,v 1.102 2003/12/20 03:21:19 guy Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
@@ -1864,7 +1864,7 @@ dissect_ieee80211_common (tvbuff_t * tvb, packet_info * pinfo,
* Fragments" indicator set *but* with a non-zero fragment
* number.
*
* "fragment_add_seq_check()" handles that; we want to call it
* even if we have a short frame, so that it does those checks - if
* the frame is short, it doesn't do reassembly on it.
*
@@ -1882,7 +1882,7 @@ dissect_ieee80211_common (tvbuff_t * tvb, packet_info * pinfo,
* whatever reassembly is in progress, if any, and see
* if it's done.
*/
- fd_head = fragment_add_seq_check(next_tvb, hdr_len, pinfo, seq_number,
+ fd_head = fragment_add_seq_802_11(next_tvb, hdr_len, pinfo, seq_number,
wlan_fragment_table,
wlan_reassembled_table,
frag_number,
@@ -1864,7 +1864,7 @@ dissect_ieee80211_common (tvbuff_t * tvb, packet_info * pinfo,
* number.
*
- * "fragment_add_seq_check()" handles that; we want to call it
+ * "fragment_add_seq_802_11()" handles that; we want to call it
* even if we have a short frame, so that it does those checks - if
* the frame is short, it doesn't do reassembly on it.